@@ -7,6 +7,9 @@ from collective.linkedin.browser.company_info import CompanyInfo
 class CustomSiteActionsViewlet(SiteActionsViewlet,CompanyInfo):
     index = ViewPageTemplateFile('templates/site_actions.pt')
 
+    def render(self):
+        return self.index()
+
     def action_visible(self):
         settings = self.get_settings()
         return settings and settings.action_popup or None
